﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;
using System.IO;
using System.Collections.ObjectModel;

namespace ReturningColumnTypesError
{
    public partial class Form1 : Form
    {
        // file streams for the serialization/deserialization
        private FileStream output;  // Stream for writing to a file.
        private FileStream input;  // Stream for reading from a file.

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.CurrentExtent = ExtentHelper.GetDrawingExtent(new RectangleShape(-180, 90, 180, -90), winformsMap1.Width, winformsMap1.Height);


            InMemoryFeatureLayer polyLayer = new InMemoryFeatureLayer();
            polyLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.SimpleColors.Green);
            polyLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            polyLayer.Open();
            polyLayer.Columns.Add(new FeatureSourceColumn("Name"));
            polyLayer.Columns.Add(new FeatureSourceColumn("Value"));

            RectangleShape poly = new RectangleShape(-20, 70, 20, -70);

            Feature polyFeature = new Feature(poly);
            polyFeature.ColumnValues.Add("Name", "Will It Show");
            polyFeature.ColumnValues.Add("Value", "111");

            polyLayer.InternalFeatures.Add("PolyFeature", polyFeature);

            LayerOverlay polyOverlay = new LayerOverlay();
            polyOverlay.Layers.Add("PolyLayer", polyLayer);
            polyOverlay.Layers["PolyLayer"].Name = "PolyLayer";
            winformsMap1.Overlays.Add("PolyOverlay", polyOverlay);
            winformsMap1.Overlays["PolyOverlay"].Name = "PolyOverlay";

            winformsMap1.Refresh();

            // Now, see what the columns are reporting
            FeatureLayer testLayer = winformsMap1.FindFeatureLayer("PolyLayer");
            foreach (Feature feature in testLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns))
            {
                MessageBox.Show("Name: " + feature.ColumnValues["Name"] + "\n\nID: " + feature.ColumnValues["Value"]);
            }

        }

        private void button1_Click(object sender, EventArgs e)
        {
            output = new FileStream(Application.StartupPath + @"\SaveFile.txt", FileMode.Create, FileAccess.Write);
            using (output)
            {
                SerializationFunctions.WriteSerializedOverlays(output, winformsMap1.Overlays);
            }

            winformsMap1.Overlays.Clear();
            winformsMap1.Refresh();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            input = new FileStream(Application.StartupPath + @"\SaveFile.txt", FileMode.Open, FileAccess.Read);
            using (input)
            {
                Collection<Overlay> overlays = SerializationFunctions.ReadSerializedOverlays(input);
                foreach (var overlay in overlays)
                {
                    LayerOverlay layerOverlay = (LayerOverlay)overlay;
                    foreach (Layer layer in layerOverlay.Layers)
                    {
                        layer.Close();
                        layer.Open();
                    }

                    winformsMap1.Overlays.Add(overlay.Name, overlay);
                }
            }

            winformsMap1.Refresh();

            // Now, see what the columns are reporting
            FeatureLayer testLayer = winformsMap1.FindFeatureLayer("PolyLayer");
            foreach (Feature feature in testLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns))
            {
                MessageBox.Show("Name: " + feature.ColumnValues["Name"] + "\n\nValue: " + feature.ColumnValues["Value"]);
            }

        }

    }
}
